import { Request, Response, NextFunction } from 'express';
import { RedisClientType } from 'redis';
export interface ExpressCacheErrorHandler {
    (error: Error, req: Request, res: Response, next: NextFunction): void;
}
export interface ExpressCacheOptions {
    /**
     * saved cache name on redis
     * format name: [key-prefix]:[tag-prefix][tag]
     * Default is "expch"
     */
    keyPrefix?: string;
    /**
     * Time to live in second. Default ttl is 60 second or 1 hour
     */
    ttl?: number;
    /**
     * Redis Client
     */
    redisClient: RedisClientType<any>;
    /**
     * Header Cache Name on Request. Default is "if-none-match":
     */
    requestHeaderName?: string;
    /**
     * Header Cache Name on Response. Default is "etag"
     */
    responseHeaderName?: string;
    /**
     * Triggered function if read cache is error
     * Default function is throw error
     */
    readCacheErrHandler?: ExpressCacheErrorHandler;
    /**
     * Triggered function if store cache is error
     * Default function is throw error
     */
    storeCacheErrHandler?: ExpressCacheErrorHandler;
    /**
     * Triggered function if clear cache is error
     * Default function is throw error
     */
    clearCacheErrHandler?: ExpressCacheErrorHandler;
}
export interface ExpressCacheMiddlewareOptions {
    /**
     * tag prefix for cache name
     * Default: string from req.path
     */
    tagPrefix?: string | ((req: Request) => string);
    /**
     * validate whether data can be cached
     * By default the data will be saved if the http status code is 200-299
     */
    isCanSaveFn?: ExpressCacheValidateFunction;
}
export interface ExpressCacheClearOptions {
    /**
     * tag pattern for cache key
     * Default: string from req.path with asterix
     * Example: users-*
     */
    tagPattern?: string | string[] | ((req: Request) => string | string[]);
    /**
     * validate whether cache can be cleared
     * By default the data will be clear if the http status code is 200-299
     */
    isCanClearFn?: ExpressCacheValidateFunction;
}
declare type ExpressCacheRequestHandler = (req: Request, res: Response, next: NextFunction) => Promise<void>;
declare type ExpressCacheValidateFunction = (httpStatusCode: number, res: Response, req: Request) => boolean;
export default class ExpressCache {
    private keyPrefix;
    private tagPrefix;
    private ttl;
    private redisClient;
    private requestHeaderName;
    private responseHeaderName;
    private readCacheErrHandler;
    private storeCacheErrHandler;
    private clearCacheErrHandler;
    constructor(opts: ExpressCacheOptions);
    middleware(opts: ExpressCacheMiddlewareOptions): ExpressCacheRequestHandler;
    private getKey;
    private getCache;
    private setCache;
    clear(opts: ExpressCacheClearOptions): ExpressCacheRequestHandler;
}
export {};
//# sourceMappingURL=index.d.ts.map