"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.responseEndOverrider = void 0;
/**
 * this function will override before response end
 * @param res Express Response
 * @param overrideFn Override Function that trigger before res.end
 */
const responseEndOverrider = (res, overrideFn) => {
    const defEnd = res.end;
    const defWrite = res.write;
    const chunks = [];
    res.write = ((...args) => {
        chunks.push(Buffer.from(args[0]));
        defWrite.apply(res, args);
    });
    res.end = ((...args) => __awaiter(void 0, void 0, void 0, function* () {
        if (args[0]) {
            chunks.push(Buffer.from(args[0]));
        }
        const resBody = Buffer.concat(chunks).toString('utf8');
        yield overrideFn(resBody);
        defEnd.apply(res, args);
    }));
};
exports.responseEndOverrider = responseEndOverrider;
